require 'cssplop'

describe CSSPlop do
  it "passes the gauntlet" do
    stylesheet = <<EOF
ul {
  padding: 0;
  margin: 0 0 1em 0;
}

#color-list {
  background-color: lightgray;
}

#color-list li {
  border-bottom: 1px solid gray;
}

#color-list li.first {
  border-top: 1px solid gray;
}
EOF

    document = <<EOF
<ul id="color-list">
  <li class="first">red</li>
  <li>green</li>
  <li class="last">blue</li>
</ul>
EOF

    expected = <<EOF
<ul id="color-list" style="padding: 0;  margin: 0 0 1em 0;  background-color: lightgray;">
<li class="first" style="border-bottom: 1px solid gray;  border-top: 1px solid gray;">red</li>
  <li style="border-bottom: 1px solid gray;">green</li>
  <li class="last" style="border-bottom: 1px solid gray;">blue</li>
</ul>
EOF

    CSSPlop.apply(stylesheet, document).should eql(expected.strip)
  end

  it "supports rulesets with multiple selectors" do
    stylesheet = <<EOF
.selector1, .selector2 {property: value;}
EOF

    document = <<EOF
<div class="selector1 selector2"></div>
<div class="selector2"></div>
EOF

    expected = <<EOF
<div class="selector1 selector2" style="property: value;"></div>
<div class="selector2" style="property: value;"></div>
EOF

    CSSPlop.apply(stylesheet, document).should eql(expected.strip)
  end

  it "supports rulesets with multiple selectors" do
    document = <<EOF
<style>* { property: value;}</style>
<div></div>
EOF

    expected = <<EOF
<div style="property: value;"></div>
EOF

    CSSPlop.inline_styles(document).should eql(expected.strip)

    document = <<EOF
<style src="http://example.com/stylesheet.css">* { nonsense: value;}</style>
<div></div>
EOF

    expected = <<EOF
<style src="http://example.com/stylesheet.css">* { nonsense: value;}</style><div></div>
EOF

    CSSPlop.inline_styles(document).should eql(expected.strip)
  end
end
